==> mediaelement-3.1.3.tgz: package/src/js/languages/it.js <==
'use strict';

/*!
 * This is a `i18n` language object.
 *
 * Italian
 *
 * @author
 *   Jalios (Twitter: @Jalios)
 *   Sascha "SoftCreatR" Greuel
 *
 * @see core/i18n.js
 */
(function (exports) {
	if (exports.it === undefined) {
		exports.it = {
			"mejs.plural-form": 1,

			// renderers/flash.js
			// "mejs.install-flash": "You are using a browser that does not have Flash player enabled or installed. Please turn on your Flash player plugin or download the latest version from https://get.adobe.com/flashplayer/",

			// features/contextmenu.js
			"mejs.fullscreen-off": "Disattivare lo schermo intero",
			"mejs.fullscreen-on": "Attivare lo schermo intero",
			"mejs.download-video": "Scaricare il video",

			// features/fullscreen.js
			"mejs.fullscreen": "Schermo intero",

			// features/jumpforward.js
			//"mejs.time-jump-forward": "Jump forward %1 second(s)",

			// features/loop.js
			//"mejs.loop": "Toggle Loop",

			// features/playpause.js
			"mejs.play": "Eseguire",
			"mejs.pause": "Pausa",

			// features/postroll.js
			"mejs.close": "Chiudere",

			// features/progress.js
			"mejs.time-slider": "Barra di scorrimento",
			"mejs.time-help-text": "Utilizzare i tasti Freccia sinistra/Freccia destra per avanzare di un secondo, Freccia Su/Giù per avanzare dieci secondi.",

			// features/skipback.js
			"mejs.time-skip-back": "Riavvolgere %1 secondi",

			// features/tracks.js
			"mejs.captions-subtitles": "Acquisizioni/sottotitoli",
			// "mejs.captions-chapters": "Chapters",
			"mejs.none": "Nessuno",

			// features/volume.js
			"mejs.volume-help-text": "Utilizzare i tasti Freccia Su/Giù per aumentare o diminuire il volume.",
			"mejs.unmute": "Disattivare muto",
			"mejs.mute": "Muto",
			"mejs.volume-slider": "Barra del volume",

			// core/player.js
			"mejs.video-player": "Lettore Video",
			"mejs.audio-player": "Lettore Audio"

			// features/ads.js
			//"mejs.ad-skip": "Skip ad",
			//"mejs.ad-skip-info": "Skip in %1 second(s)",

			// features/sourcechooser.js
			//"mejs.source-chooser": "Source Chooser",

			// features/stop.js
			//"mejs.stop": "Stop",

			//features/speed.js
			//"mejs.speed-rate" : "Speed Rate",

			//features/progress.js
			//"mejs.live-broadcast" : "Live Broadcast",

			// features/tracks.js
			// "mejs.afrikaans": "Afrikaans",
			// "mejs.albanian": "Albanian",
			// "mejs.arabic": "Arabic",
			// "mejs.belarusian": "Belarusian",
			// "mejs.bulgarian": "Bulgarian",
			// "mejs.catalan": "Catalan",
			// "mejs.chinese": "Chinese",
			// "mejs.chinese-simplified": "Chinese (Simplified)",
			// "mejs.chinese-traditional": "Chinese (Traditional)",
			// "mejs.croatian": "Croatian",
			// "mejs.czech": "Czech",
			// "mejs.danish": "Danish",
			// "mejs.dutch": "Dutch",
			// "mejs.english": "English",
			// "mejs.estonian": "Estonian",
			// "mejs.filipino": "Filipino",
			// "mejs.finnish": "Finnish",
			// "mejs.french": "French",
			// "mejs.galician": "Galician",
			// "mejs.german": "German",
			// "mejs.greek": "Greek",
			// "mejs.haitian-creole": "Haitian Creole",
			// "mejs.hebrew": "Hebrew",
			// "mejs.hindi": "Hindi",
			// "mejs.hungarian": "Hungarian",
			// "mejs.icelandic": "Icelandic",
			// "mejs.indonesian": "Indonesian",
			// "mejs.irish": "Irish",
			// "mejs.italian": "Italian",
			// "mejs.japanese": "Japanese",
			// "mejs.korean": "Korean",
			// "mejs.latvian": "Latvian",
			// "mejs.lithuanian": "Lithuanian",
			// "mejs.macedonian": "Macedonian",
			// "mejs.malay": "Malay",
			// "mejs.maltese": "Maltese",
			// "mejs.norwegian": "Norwegian",
			// "mejs.persian": "Persian",
			// "mejs.polish": "Polish",
			// "mejs.portuguese": "Portuguese",
			// "mejs.romanian": "Romanian",
			// "mejs.russian": "Russian",
			// "mejs.serbian": "Serbian",
			// "mejs.slovak": "Slovak",
			// "mejs.slovenian": "Slovenian",
			// "mejs.spanish": "Spanish",
			// "mejs.swahili": "Swahili",
			// "mejs.swedish": "Swedish",
			// "mejs.tagalog": "Tagalog",
			// "mejs.thai": "Thai",
			// "mejs.turkish": "Turkish",
			// "mejs.ukrainian": "Ukrainian",
			// "mejs.vietnamese": "Vietnamese",
			// "mejs.welsh": "Welsh",
			// "mejs.yiddish": "Yiddish"
		};
	}
})(mejs.i18n);

==> mediaelement-3.2.1.tgz: package/src/js/languages/it.js <==
'use strict';

/*!
 * This is a `i18n` language object.
 *
 * Italian
 *
 * @author
 *   Jalios (Twitter: @Jalios)
 *   Sascha "SoftCreatR" Greuel
 *
 * @see core/i18n.js
 */
(function (exports) {
	if (exports.it === undefined) {
		exports.it = {
			"mejs.plural-form": 1,

			// renderers/flash.js
			// "mejs.install-flash": "You are using a browser that does not have Flash player enabled or installed. Please turn on your Flash player plugin or download the latest version from https://get.adobe.com/flashplayer/",

			// features/fullscreen.js
			"mejs.fullscreen": "Schermo intero",

			// features/playpause.js
			"mejs.play": "Eseguire",
			"mejs.pause": "Pausa",

			// features/progress.js
			"mejs.time-slider": "Barra di scorrimento",
			"mejs.time-help-text": "Utilizzare i tasti Freccia sinistra/Freccia destra per avanzare di un secondo, Freccia Su/Giù per avanzare dieci secondi.",
			//"mejs.live-broadcast" : "Live Broadcast",

			// features/volume.js
			"mejs.volume-help-text": "Utilizzare i tasti Freccia Su/Giù per aumentare o diminuire il volume.",
			"mejs.unmute": "Disattivare muto",
			"mejs.mute": "Muto",
			"mejs.volume-slider": "Barra del volume",

			// core/player.js
			"mejs.video-player": "Lettore Video",
			"mejs.audio-player": "Lettore Audio",

			// features/tracks.js
			"mejs.captions-subtitles": "Acquisizioni/sottotitoli",
			// "mejs.captions-chapters": "Chapters",
			"mejs.none": "Nessuno"
			// "mejs.afrikaans": "Afrikaans",
			// "mejs.albanian": "Albanian",
			// "mejs.arabic": "Arabic",
			// "mejs.belarusian": "Belarusian",
			// "mejs.bulgarian": "Bulgarian",
			// "mejs.catalan": "Catalan",
			// "mejs.chinese": "Chinese",
			// "mejs.chinese-simplified": "Chinese (Simplified)",
			// "mejs.chinese-traditional": "Chinese (Traditional)",
			// "mejs.croatian": "Croatian",
			// "mejs.czech": "Czech",
			// "mejs.danish": "Danish",
			// "mejs.dutch": "Dutch",
			// "mejs.english": "English",
			// "mejs.estonian": "Estonian",
			// "mejs.filipino": "Filipino",
			// "mejs.finnish": "Finnish",
			// "mejs.french": "French",
			// "mejs.galician": "Galician",
			// "mejs.german": "German",
			// "mejs.greek": "Greek",
			// "mejs.haitian-creole": "Haitian Creole",
			// "mejs.hebrew": "Hebrew",
			// "mejs.hindi": "Hindi",
			// "mejs.hungarian": "Hungarian",
			// "mejs.icelandic": "Icelandic",
			// "mejs.indonesian": "Indonesian",
			// "mejs.irish": "Irish",
			// "mejs.italian": "Italian",
			// "mejs.japanese": "Japanese",
			// "mejs.korean": "Korean",
			// "mejs.latvian": "Latvian",
			// "mejs.lithuanian": "Lithuanian",
			// "mejs.macedonian": "Macedonian",
			// "mejs.malay": "Malay",
			// "mejs.maltese": "Maltese",
			// "mejs.norwegian": "Norwegian",
			// "mejs.persian": "Persian",
			// "mejs.polish": "Polish",
			// "mejs.portuguese": "Portuguese",
			// "mejs.romanian": "Romanian",
			// "mejs.russian": "Russian",
			// "mejs.serbian": "Serbian",
			// "mejs.slovak": "Slovak",
			// "mejs.slovenian": "Slovenian",
			// "mejs.spanish": "Spanish",
			// "mejs.swahili": "Swahili",
			// "mejs.swedish": "Swedish",
			// "mejs.tagalog": "Tagalog",
			// "mejs.thai": "Thai",
			// "mejs.turkish": "Turkish",
			// "mejs.ukrainian": "Ukrainian",
			// "mejs.vietnamese": "Vietnamese",
			// "mejs.welsh": "Welsh",
			// "mejs.yiddish": "Yiddish"
		};
	}
})(mejs.i18n);
